@@ -40,17 +40,24 @@ class PostGISDB(object):
     @property
     def connection(self):
         if not self._connection:
+            kw = {}
+            if self.db_conf.port:
+                kw['port'] = int(self.db_conf.port)
             self._connection = psycopg2.connect(
                 database=self.db_conf.db,
                 host=self.db_conf.host,
                 user=self.db_conf.user,
                 password=self.db_conf.password,
                 sslmode=self.db_conf.get('sslmode', 'allow'),
+                **kw
             )
             self._connection.set_isolation_level(
                 psycopg2.extensions.ISOLATION_LEVEL_READ_COMMITTED)
         return self._connection
     
+    def commit(self):
+        self.connection.commit()
+    
     @property
     def cur(self):
         if self._cur is None:
@@ -84,8 +91,8 @@ class PostGISDB(object):
 
         self.connection.commit()
     
-    def wkb_wrapper(self, wkb):
-        return psycopg2.Binary(wkb)
+    def geom_wrapper(self, geom):
+        return psycopg2.Binary(geom.wkb)
     
     def reconnect(self):
         if self._connection:
@@ -273,7 +280,6 @@ class PostGISUnionView(object):
 
         stmt = 'CREATE OR REPLACE VIEW "%s" as (\n%s\n)' % (self.view_name, selects)
         
-        print stmt
         return stmt
 
     def _geom_table_stmt(self):
@@ -330,9 +336,16 @@ class PostGISGeneralizedTable(object):
 
     def _stmt(self):
         fields = ', '.join([n for n, t in self.mapping.fields])
-        return """CREATE TABLE "%s" AS (SELECT osm_id, name, type, %s,
-            ST_Simplify(geometry, %f) as geometry from "%s")""" % (
-            self.table_name, fields, self.mapping.tolerance, self.db.to_tablename(self.mapping.origin.name))
+        if fields:
+            fields += ','
+        if self.mapping.where:
+            where = ' WHERE ' + self.mapping.where
+        else:
+            where = ''
+        return """CREATE TABLE "%s" AS (SELECT osm_id, name, type, %s
+            ST_Simplify(geometry, %f) as geometry from "%s"%s)""" % (
+            self.table_name, fields, self.mapping.tolerance, self.db.to_tablename(self.mapping.origin.name),
+            where)
 
     def create(self):
         cur = self.db.connection.cursor()
